@@ -10,9 +10,8 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccRTP.  If not, see <http://www.gnu.org/licenses/>.
 //
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
@@ -45,6 +44,8 @@
 #define CCXX_RTP_CQUEUE_H_
 
 #include <ccrtp/ioqueue.h>
+#include <ccrtp/CryptoContextCtrl.h>
+#include <list>
 
 NAMESPACE_COMMONCPP
 
@@ -176,6 +177,73 @@ public:
     getSendRTCPPacketCount() const
     { return ctrlSendCount; }
 
+    /**
+     * Set ouput queue CryptoContext.
+     *
+     * The endQueue method (provided by RTPQueue) deletes all
+     * registered CryptoContexts.
+     *
+     * @param cc Pointer to initialized CryptoContext.
+     */
+    void
+    setOutQueueCryptoContextCtrl(CryptoContextCtrl* cc);
+
+    /**
+     * Remove output queue CryptoContext.
+     *
+     * The endQueue method (provided by RTPQueue) also deletes all
+     * registered CryptoContexts.
+     *
+     * @param cc Pointer to initialized CryptoContext to remove.
+     */
+    void
+    removeOutQueueCryptoContextCtrl(CryptoContextCtrl* cc);
+
+    /**
+     * Get an output queue CryptoContext identified by SSRC
+     *
+     * @param ssrc Request CryptoContext for this incoming SSRC
+     * @return Pointer to CryptoContext of the SSRC of NULL if no context
+     * available for this SSRC.
+     */
+    CryptoContextCtrl*
+    getOutQueueCryptoContextCtrl(uint32 ssrc);
+
+
+    /**
+     * Set input queue CryptoContext.
+     *
+     * The endQueue method (provided by RTPQueue) deletes all
+     * registered CryptoContexts.
+     *
+     * @param cc Pointer to initialized CryptoContext.
+     */
+    void
+    setInQueueCryptoContextCtrl(CryptoContextCtrl* cc);
+
+    /**
+     * Remove input queue CryptoContext.
+     *
+     * The endQueue method (provided by RTPQueue) also deletes all
+     * registered CryptoContexts.
+     *
+     * @param cc
+     *     Pointer to initialized CryptoContext to remove. If pointer
+     *     if <code>NULL</code> then delete the whole queue
+     */
+    void
+    removeInQueueCryptoContextCtrl(CryptoContextCtrl* cc);
+
+    /**
+     * Get an input queue CryptoContext identified by SSRC
+     *
+     * @param ssrc Request CryptoContext for this incoming SSRC
+     * @return Pointer to CryptoContext of the SSRC of NULL if no context
+     * available for this SSRC.
+     */
+    CryptoContextCtrl*
+    getInQueueCryptoContextCtrl(uint32 ssrc);
+
 protected:
     QueueRTCPManager(uint32 size = RTPDataQueue::defaultMembersHashSize,
              RTPApplication& app = defaultApplication());
@@ -550,6 +618,11 @@ private:
     transportHeaderSize()
     { return 8; }
 
+
+    int32 protect(uint8* pkt, size_t len, CryptoContextCtrl* cc);
+    int32 unprotect(uint8* pkt, size_t len, CryptoContextCtrl* cc);
+    
+    
     SDESItemType
     nextSDESType(SDESItemType t);
 
@@ -615,6 +688,14 @@ private:
     // an empty RTPData
     static const uint16 TIMEOUT_MULTIPLIER;
     static const double RECONSIDERATION_COMPENSATION;
+    
+    mutable Mutex outCryptoMutex;
+    std::list<CryptoContextCtrl *> outCryptoContexts;
+    uint32 srtcpIndex;
+
+    mutable Mutex inCryptoMutex;
+    std::list<CryptoContextCtrl *> inCryptoContexts;
+
 };
 
 /**
