@@ -10,9 +10,8 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccRTP.  If not, see <http://www.gnu.org/licenses/>.
 //
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
@@ -402,7 +401,7 @@ private:
      **/
     struct RTPFixedHeader
     {
-#if __BYTE_ORDER == __BIG_ENDIAN
+#if defined(__BYTE_ORDER) && __BYTE_ORDER == __BIG_ENDIAN
         /// For big endian boxes
         unsigned char version:2;       ///< Version, currently 2
         unsigned char padding:1;       ///< Padding bit
@@ -435,7 +434,7 @@ private:
 public:
     struct RFC2833Payload
     {
-#if __BYTE_ORDER == __BIG_ENDIAN
+#if defined(__BYTE_ORDER) && __BYTE_ORDER == __BIG_ENDIAN
             uint8 event : 8;
             bool ebit : 1;
             bool rbit : 1;
